@@ -32,9 +32,14 @@ class Policy(object):
     installation as open-ish, or closed-ish.
     """
 
+    attributes = [
+            'read', 'write', 'create', 'delete', 'manage',
+            'accept', 'owner'
+            ]
+
     def __init__(self, owner=None,
             read=None, write=None, create=None, delete=None,
-            manage=None):
+            manage=None, accept=None):
         # avoid "dangerous" warnings from pylint and
         # and possible memory leaks
         if read is None:
@@ -47,12 +52,15 @@ class Policy(object):
             delete = []
         if manage is None:
             manage = []
+        if accept is None:
+            accept = []
         self.owner = owner
         self.read = read
         self.write = write
         self.create = create
         self.delete = delete
         self.manage = manage
+        self.accept = accept
 
     def allows(self, user, constraint):
         """
